@@ -136,6 +136,13 @@ class DiagramTreeBuilder:
                     if nw:
                         self.diagram.networks.append(nw)
 
+            elif isinstance(stmt, diagparser.Route):
+                nodes = [DiagramNode.get(n) for n in stmt.nodes]
+                for node1, node2 in zip(nodes[:-1], nodes[1:]):
+                    route = Route(node1, node2)
+                    route.set_attributes(stmt.attrs)
+                    self.diagram.routes.append(route)
+
             elif isinstance(stmt, diagparser.DefAttrs):
                 self.diagram.set_attributes(stmt.attrs)
 
@@ -220,8 +227,8 @@ class DiagramLayoutManager:
         self.set_group_size(group)
 
         xy = group.xy
-        for i in range(xy.x, xy.x + group.width):
-            for j in range(xy.y, xy.y + group.height):
+        for i in range(xy.x, xy.x + group.colwidth):
+            for j in range(xy.y, xy.y + group.colheight):
                 self.coordinates.append(XY(i, j))
 
     def set_network_size(self):
@@ -233,7 +240,7 @@ class DiagramLayoutManager:
             network.xy = XY(x0, network.xy.y)
 
             x1 = max(n.xy.x for n in nodes)
-            network.width = x1 - x0 + 1
+            network.colwidth = x1 - x0 + 1
 
     def set_group_size(self, group):
         nodes = list(group.nodes)
@@ -245,8 +252,8 @@ class DiagramLayoutManager:
 
         x1 = max(n.xy.x for n in nodes)
         y1 = max(n.xy.y for n in nodes)
-        group.width = x1 - x0 + 1
-        group.height = y1 - y0 + 1
+        group.colwidth = x1 - x0 + 1
+        group.colheight = y1 - y0 + 1
 
 
 class ScreenNodeBuilder:
