@@ -57,8 +57,8 @@ class Network(blockdiag.elements.NodeGroup):
 
         self.address = None
         self.hidden = False
-        self.width = 0
-        self.height = 0
+        self.colwidth = 1
+        self.colheight = 1
 
     @classmethod
     def create_anonymous(klass, nodes, attrs=[]):
@@ -96,9 +96,14 @@ class Network(blockdiag.elements.NodeGroup):
         return label
 
 
+class Route(blockdiag.elements.DiagramEdge):
+    pass
+
+
 class Diagram(blockdiag.elements.Diagram):
     _DiagramNode = DiagramNode
     _Network = Network
+    _Route = Route
 
     def set_default_line_color(self, color):
         super(Diagram, self).set_default_line_color(color)
@@ -117,9 +122,10 @@ class Diagram(blockdiag.elements.Diagram):
         self.span_height = 104
         self.groups = []
         self.networks = []
+        self.routes = []
 
     def fixiate(self):
         if len(self.nodes) + len(self.networks) > 0:
             nodes = self.nodes + self.networks
-            self.width = max(x.xy.x + x.width for x in nodes)
-            self.height = max(x.xy.y + x.height for x in nodes)
+            self.colwidth = max(x.xy.x + x.colwidth for x in nodes)
+            self.colheight = max(x.xy.y + x.colheight for x in nodes)
